***************************************************************
* STATA Do file for:				 	     		  *
*							                    *
* Matthew Fuhrmann and Sarah Kreps, "Targeting Nuclear	  *
* Programs in War and Peace: A Quantitative Empirical         *    
* Analysis, 1942-2000, Journal of Conflict Resolution"	  *
*  	                                                        *
* Do files written for use in STATA 10.0			        *
* 	                   						  *
***************************************************************

****************************************************************************************************************************************
*Table 3: Cross-Tab Analysis
****************************************************************************************************************************************
tab consider1 s_un_regDUM if polrel==1 & cap_2~=. & s_un_reg~=. &  hostileMID~=. & polity2~=. & prgmyrs~=. & NCAnosafetodate~=. & cap_1~=. & contig~=. , chi2 column
tab attack1 s_un_regDUM if polrel==1 & cap_2~=. & s_un_reg~=. &  hostileMID~=. & polity2~=. & prgmyrs~=. & NCAnosafetodate~=. & cap_1~=. & contig~=. , chi2 column
tab consider1 hostileMID if polrel==1 & cap_2~=. & s_un_reg~=. &  hostileMID~=. & polity2~=. & prgmyrs~=. & NCAnosafetodate~=. & cap_1~=. & contig~=. , chi2 column
tab attack1 hostileMID if polrel==1 & cap_2~=. & s_un_reg~=. &  hostileMID~=. & polity2~=. & prgmyrs~=. & NCAnosafetodate~=. & cap_1~=. & contig~=. , chi2 column
tab consider1 polity2DUM if polrel==1 & cap_2~=. & s_un_reg~=. &  hostileMID~=. & polity2~=. & prgmyrs~=. & NCAnosafetodate~=. & cap_1~=. & contig~=. , chi2 column
tab attack1 polity2DUM if polrel==1 & cap_2~=. & s_un_reg~=. &  hostileMID~=. & polity2~=. & prgmyrs~=. & NCAnosafetodate~=. & cap_1~=. & contig~=. , chi2 column

****************************************************************************************************************************************
*Table 4: First-Cut Statistical Results (Models 1-6)
****************************************************************************************************************************************
relogit consider1 hostileMID polity2 s_un_reg  noconsideryrs _spline1 _spline2 _spline3 if polrel==1, cluster(dyadid)
relogit consider1 hostileMID polity2 s_un_reg  cap_2 pwrratio postArt56 postCW prgmyrs NCAnosafetodate cap_1 contig noconsideryrs _spline1 _spline2 _spline3 if polrel==1, cluster(dyadid)
relogit consider1 hostileMID postArt56 postCW prgmyrs NCAnosafetodate noconsideryrs _spline1 _spline2 _spline3 if polrel==1, cluster(dyadid)
relogit attack1 hostileMID polity2 s_un_reg  noattackyrs _spline1a _spline2a _spline3a if polrel==1, cluster(dyadid)
relogit attack1 hostileMID polity2 s_un_reg  cap_2 pwrratio postArt56 postCW prgmyrs NCAnosafetodate cap_1 contig noattackyrs _spline1a _spline2a _spline3a if polrel==1, cluster(dyadid)
relogit attack1 hostileMID postArt56 postCW prgmyrs NCAnosafetodate noattackyrs _spline1a _spline2a _spline3a if polrel==1, cluster(dyadid)

****************************************************************************************************************************************
*Table 5: Analysis of War, Democracy, and Attacks against Nuclear Programs (Models 7-8)
****************************************************************************************************************************************
relogit attack1 hostileMID pol2corr pol2corrXhostileMID noattackyrs _spline1a _spline2a _spline3a if polrel==1, cluster(dyadid)
relogit attack1 hostileMID pol2corr pol2corrXhostileMID s_un_reg cap_2 pwrratio postArt56 postCW prgmyrs NCAnosafetodate cap_1 contig  noattackyrs _spline1a _spline2a _spline3a if polrel==1, cluster(dyadid)

****************************************************************************************************************************************
*Figure 1: Marginal Effect of War on Attacks against Nuclear Facilities as Target's Polity Score Increases
****************************************************************************************************************************************
summarize  attack1 hostileMID NCAnosafetodate prgmyrs cap_1 contig noattackyrs _spline1a _spline2a _spline3a if polrel==1
#delimit;
probit attack1 hostileMID pol2corr pol2corrXhostileMID s_un_reg cap_2 pwrratio postArt56 postCW prgmyrs NCAnosafetodate cap_1 contig  noattackyrs _spline1a _spline2a _spline3a if polrel==1, cluster(dyadid);
preserve;
drawnorm MF_b1-MF_b17, n(10000) means(e(b)) cov(e(V)) clear;
postutil clear;
postfile mypost prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi using sim , replace;
            noisily display "start";         
local a=0; 
while `a' <= 20  {;
quietly display "got here";
quietly {;
scalar h_hostileMID=0;
scalar h_s_un_reg=.44;
scalar h_cap_2=.023;
scalar h_pwrratio=9.41;
scalar h_postArt56=1;
scalar h_postCW=1;
scalar h_prgmyrs=12.69;
scalar h_NCAnosafetodate=9.37;
scalar h_cap_1=.046;
scalar h_contig=1;
scalar h_noattackyrs=11.37;
scalar h__spline1a=-1499;
scalar h__spline2a=-2321;
scalar h__spline3a=-2246;
scalar h_constant=1;

    generate x_betahat0 = MF_b1*h_hostileMID
                            + MF_b2*(`a')
                            + MF_b3*h_hostileMID*(`a')
                            + MF_b4*h_s_un_reg
                            + MF_b5*h_cap_2
                            + MF_b6*h_pwrratio
                            + MF_b7*h_postArt56
                            + MF_b8*h_postCW
                            + MF_b9*h_prgmyrs
                            + MF_b10*h_NCAnosafetodate
                            + MF_b11*h_cap_1
                            + MF_b12*h_contig
                            + MF_b13*h_noattackyrs
                            + MF_b14*h__spline1a
                            + MF_b15*h__spline2a
                            + MF_b16*h__spline3a
                            + MF_b17*h_constant;                             
    generate x_betahat1 = MF_b1*(h_hostileMID+1)
                            + MF_b2*(`a')
                            + MF_b3*(h_hostileMID+1)*(`a')
                            + MF_b4*h_s_un_reg
                            + MF_b5*h_cap_2
                            + MF_b6*h_pwrratio
                            + MF_b7*h_postArt56
                            + MF_b8*h_postCW
                            + MF_b9*h_prgmyrs
                            + MF_b10*h_NCAnosafetodate
                            + MF_b11*h_cap_1
                            + MF_b12*h_contig
                            + MF_b13*h_noattackyrs
                            + MF_b14*h__spline1a
                            + MF_b15*h__spline2a
                            + MF_b16*h__spline3a
                            + MF_b17*h_constant;                             
    
   gen prob0=normal(x_betahat0);
    gen prob1=normal(x_betahat1);
    gen diff=prob1-prob0;
    
    egen probhat0=mean(prob0);
    egen probhat1=mean(prob1);
    egen diffhat=mean(diff);
    
    tempname prob_hat0 lo0 hi0 prob_hat1 lo1 hi1 diff_hat diff_lo diff_hi ;  

    _pctile prob0, p(5,95) ;
    scalar `lo0' = r(r1);
    scalar `hi0' = r(r2);  
    
    _pctile prob1, p(5,95);
    scalar `lo1'= r(r1);
    scalar `hi1'= r(r2);  
    
    _pctile diff, p(5,95);
    scalar `diff_lo'= r(r1);
    scalar `diff_hi'= r(r2);  
  
    scalar `prob_hat0'=probhat0;
    scalar `prob_hat1'=probhat1;
    scalar `diff_hat'=diffhat;
    
    post mypost (`prob_hat0') (`lo0') (`hi0') (`prob_hat1') (`lo1') (`hi1') 
                (`diff_hat') (`diff_lo') (`diff_hi') ;
    };      
    drop x_betahat0 x_betahat1 prob0 prob1 diff probhat0 probhat1 diffhat ;
    local a=`a'+ 1 ;
    display "." _c;
    } ;
display "";
postclose mypost;
use sim, clear;
gen MV = _n-1;
graph twoway line diff_hat MV, clwidth(medium) clcolor(blue) clcolor(black)
        ||   line diff_lo  MV, clpattern(dash) clwidth(thin) clcolor(black)
        ||   line diff_hi  MV, clpattern(dash) clwidth(thin) clcolor(black)
        ||  ,   
            xlabel( 0 2 4 6 8 10 12 14 16 18 20, labsize(3)) 
            ylabel(-.01 0 .01 .02 .03 .04 .05 .06 .07 .08 .09 .1, labsize(3))
            yscale(noline)
            xscale(noline)

            legend(off)
            title("", size(4))
            subtitle(" " "" " ", size(3))
            xtitle(Target's Polity Score, size(3.5)  )
            ytitle("Marginal Effect of Violent Conflict", size(3.5))
            xsca(titlegap(2))
            ysca(titlegap(2))
            scheme(s2mono) graphregion(fcolor(white));
graph save "C:\Documents and Settings\Fuhrmann\Desktop\Targeting Nuclear Programs\Figure 1.gph", replace

****************************************************************************************************************************************
*Table 6: Accounting for Possible Missing Considered Attacks (Models 9-11)
****************************************************************************************************************************************
relogit consider1 s_un_reg  hostileMID polity2 noconsideryrs _spline1 _spline2 _spline3 if polrel==1 & polity1>6, cluster(dyadid)
relogit consider1 s_un_reg  hostileMID polity2 cap_2 pwrratio postArt56 postCW prgmyrs NCAnosafetodate cap_1 contig noconsideryrs _spline1 _spline2 _spline3 if polrel==1 & polity1>6, cluster(dyadid)
relogit consider1 hostileMID postArt56 postCW prgmyrs NCAnosafetodate noconsideryrs _spline1 _spline2 _spline3 if polrel==1 & polity1>6, cluster(dyadid)


